@@ -2,12 +2,12 @@ use strict;
 use warnings;
 package Data::Rx::CoreType::bool;
 {
-  $Data::Rx::CoreType::bool::VERSION = '0.200000'; # TRIAL
+  $Data::Rx::CoreType::bool::VERSION = '0.200001'; # TRIAL
 }
-use base 'Data::Rx::CoreType';
+use parent 'Data::Rx::CoreType';
 # ABSTRACT: the Rx //bool type
 
-sub validate {
+sub assert_valid {
   my ($self, $value) = @_;
 
   return 1 if (
@@ -42,7 +42,7 @@ Data::Rx::CoreType::bool - the Rx //bool type
 
 =head1 VERSION
 
-version 0.200000
+version 0.200001
 
 =head1 AUTHOR
 
